Learn R Programming

rdryad (version 0.2.0)

dr_list_identifiers: Gets OAI Dryad identifiers

Description

Gets OAI Dryad identifiers

Usage

dr_list_identifiers(prefix = "oai_dc", from = NULL, until = NULL, set = "hdl_10255_3", token = NULL, as = "df", ...)

Arguments

prefix
A character string to specify the metadata format in OAI-PMH requests issued to the repository. The default ("oai_dc") corresponds to the mandatory OAI unqualified Dublin Core metadata schema.
from
Character string giving datestamp to be used as lower bound for datestamp-based selective harvesting (i.e., only harvest records with datestamps in the given range). Dates and times must be encoded using ISO 8601. The trailing Z must be used when including time. OAI-PMH implies UTC for data/time specifications.
until
Character string giving a datestamp to be used as an upper bound, for datestamp-based selective harvesting (i.e., only harvest records with datestamps in the given range).
set
A character string giving a set to be used for selective harvesting (i.e., only harvest records in the given set).
token
(character) a token previously provided by the server to resume a request where it last left off. 50 is max number of records returned. We will loop for you internally to get all the records you asked for.
as
(character) What to return. One of "df" (for data.frame; default), "list", or "raw" (raw text)
...
Curl debugging options passed on to GET

Value

XML character string, data.frame, or list, depending on what requested witht the as parameterList of OAI identifiers for each dataset.

Examples

Run this code
## Not run: 
# dr_list_identifiers(from='2010-01-01', until = "2010-06-30")
# dr_list_identifiers(set="geocode1", from='2015-09-01', until='2015-09-05')
# dr_list_identifiers(prefix="iso19139", from='2015-09-01', until='2015-09-20')
# dr_list_identifiers(prefix="dif", from='2015-09-01', until='2015-09-20')
# 
# identifiers <- dr_list_identifiers('r')
# 
# # Data packages
# identifiers[[1]]
# 
# # Data files
# identifiers[[2]]
# ## End(Not run)

Run the code above in your browser using DataLab