Learn R Programming

rdryad (version 0.4.0)

dr_list_sets: List the sets in the Dryad metadata repository.

Description

Retrieve the set structure of Dryad, useful for selective harvesting

Usage

dr_list_sets(token = NULL, as = "df", ...)

Arguments

token

(character) a token previously provided by the server to resume a request where it last left off. 50 is max number of records returned. We will loop for you internally to get all the records you asked for.

as

(character) What to return. One of "df" (for data.frame; default), "list", or "raw" (raw text)

...

Curl debugging options passed on to httr::GET

Examples

Run this code
# NOT RUN {
dr_list_sets()
dr_list_sets(as = "list")
dr_list_sets(as = "raw")
# }

Run the code above in your browser using DataLab