Learn R Programming

rdryad (version 0.1.1)

totimp: Get Total Impact (http://totalimpact.org/) metrics or bibliography on a paper.

Description

Get Total Impact (http://totalimpact.org/) metrics or bibliography on a paper.

Usage

totimp(id = NA, fields = "metrics", sleep = 0,
    url = "http://total-impact.org/api/v1/items/")

Arguments

id
The DOI, URL, or PubMed ID - see examples.
fields
One of 'metrics' or 'biblio'.
sleep
Time (in seconds) before function sends API call - defaults to zero. Set to higher number if you are using this function in a loop with many API calls. Although, with TotalImpact, you can also just put in multiple id's in one call (much faster) i
url
The base URL (do not change from default).

Value

  • A list.

Examples

Run this code
totimp(id = '10.5061/dryad.8671')
totimp(id = '10.5061/dryad.8671', 'biblio')
totimp(id = list('10.5061/dryad.8671','18428094','http://opensciencesummit.com/program/'), 'biblio')
totimp(id = '18428094', 'biblio')

Run the code above in your browser using DataLab