Learn R Programming

rdryad (version 0.1.1)

totimp_dryad: Get Dryad metrics from Total Impact (http://totalimpact.org/) API.

Description

Get Dryad metrics from Total Impact (http://totalimpact.org/) API.

Usage

totimp_dryad(id = NA, sleep = 0,
    url = "http://total-impact.org/api/v1/items/")

Arguments

id
The Dryad identifier - see examples.
sleep
Time (in seconds) before function sends API call - defaults to zero. Set to higher number if you are using this function in a loop with many API calls. Although, with TotalImpact, you can also just put in multiple id's in one call (much faster) i
url
The base URL (do not change from default).

Value

  • A data.frame, or list of data.frame's, of results.

Examples

Run this code
totimp_dryad(id = '10.5061/dryad.8671')
totimp_dryad(id = list('10.5061/dryad.8671', '10.5061/dryad.8908'))

Run the code above in your browser using DataLab