Learn R Programming

rdryad (version 0.2.0)

dr_get_records: Download metadata for individual Dryad id's

Description

Download metadata for individual Dryad id's

Usage

dr_get_records(ids, prefix = "oai_dc", as = "df", ...)

Arguments

ids
Dryad identifier, i.e. oai:datadryad.org:10255/dryad.8820
prefix
A character string to specify the metadata format in OAI-PMH requests issued to the repository. The default ("oai_dc") corresponds to the mandatory OAI unqualified Dublin Core metadata schema.
as
(character) What to return. One of "df" (for data.frame; default), "list", or "raw" (raw text)
...
Curl debugging options passed on to GET

Value

XML character string, data.frame, or list, depending on what requested witht the as parameter

Examples

Run this code
## Not run: 
# dr_get_records(ids = 'oai:datadryad.org:10255/dryad.8820')
# handles <- c('10255/dryad.36217', '10255/dryad.86943', '10255/dryad.84720', '10255/dryad.34100')
# ids <- paste0('oai:datadryad.org:', handles)
# dr_get_records(ids)
# ## End(Not run)

Run the code above in your browser using DataLab