Includes access to Dryad's Solr API, OAI-PMH service, and part of their REST API.
Package API
The functions match the three major sets of Dryad API routes for datasets, fiiles and versions.
Datasets:
Files:
Versions:
Defunct
The Dryad Solr API is no longer being updated, so the functions that used to work with it are all defunct, see solr-defunct
The Dryad OAI-PMH service is no longer being updated, so the functions that used to work with it are all defunct, see oai-defunct
More defunct functions:
Author
Maintainer: Scott Chamberlain myrmecocystus@gmail.com (ORCID)
Authors:
Scott Chamberlain myrmecocystus@gmail.com (ORCID)
Karthik Ram (ORCID)
Carl Boettiger (ORCID)